package cn.estsh.i3plus.core.apiservice.util;

import cn.estsh.i3plus.platform.common.tool.TimeTool;
import cn.estsh.i3plus.platform.plugin.elasticsearch.ElasticSearchPack;
import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.tool.BsonPackTool;
import cn.estsh.i3plus.pojo.platform.platbean.*;
import com.mongodb.BasicDBObject;
import org.apache.commons.lang3.StringUtils;
import org.bson.conversions.Bson;

/**
 * @Description :
 * @Reference :
 * @Author : wei.peng
 * @CreateDate : 20-3-10 下午4:12
 * @Modify:
 **/
public class NoSqlPack {
    /**
     * Es 查询构建基类
     * @param bean
     * @return
     */
    public static ElasticSearchPack packElasticSearchPack(BaseBean bean){
        ElasticSearchPack result = null;
        if(StringUtils.isNotBlank(bean.getCreateDatetime())){
            result = ElasticSearchPack.imppBuild(TimeTool.parseDate(bean.getCreateDatetime()),bean.getClass());
        }else{
            result = ElasticSearchPack.imppBuild(bean.getClass());
        }

        if(StringUtils.isNotBlank(bean.getOrderByParam())){
            if(CommonEnumUtil.ASC_OR_DESC.ASC.getValue() == bean.getAscOrDesc()){
                result.asc(bean.getOrderByParam());
            }else {
                result.desc(bean.getOrderByParam());
            }
        }else{
            result.orderKeywordDesc("createDatetime");
        }
        return result;
    }

    /**
     * 系统异常日志复杂查询
     *
     * @param sysLogException
     * @return
     */
    public static Bson packMongoBySysLogException(SysLogException sysLogException) {
        Bson bson = new BasicDBObject();

        bson = BsonPackTool.getNumEqualPack(sysLogException.getExcModule(), "excModule", bson);
        bson = BsonPackTool.getStringLikerPack(sysLogException.getExcMessage(), "excMessage", bson);
        bson = BsonPackTool.timeBuilder("createDatetime", bson, sysLogException.getCreateDateTimeStart(),sysLogException.getCreateDateTimeEnd());

        return bson;
    }

    public static ElasticSearchPack packEsSysLogException(SysLogException bean) {
        ElasticSearchPack result = packElasticSearchPack(bean);

        result.andTextEquals("excModule",bean.getExcModule());
        result.andKeywordLike("excMessage",bean.getExcMessage());
        result.andKeywordDateTimeBetween("createDatetime",bean.getCreateDateTimeStart(),bean.getCreateDateTimeEnd());

        return result;
    }

    /**
     * 系统操作日志
     *
     * @param logOperate
     * @return
     */
    public static Bson packMongoByLogOperate(SysLogOperate logOperate) {
        Bson bson = new BasicDBObject();

        bson = BsonPackTool.getNumEqualPack(logOperate.getId(), "id", bson);
        bson = BsonPackTool.getNumEqualPack(logOperate.getOperateType(), "operateType", bson);
        bson = BsonPackTool.getNumEqualPack(logOperate.getOperateModule(), "operateModule", bson);
        bson = BsonPackTool.timeBuilder("createDatetime", bson, logOperate.getCreateDateTimeStart(),logOperate.getCreateDateTimeEnd());
        bson = BsonPackTool.getStringLikerPack(logOperate.getRemoteIp(), "remoteIp", bson);
        bson = BsonPackTool.getStringLikerPack(logOperate.getOperateMessage(), "operateMessage", bson);
        bson = BsonPackTool.getStringLikerPack(logOperate.getCreateUser(), "createUser", bson);

        return bson;
    }

    public static ElasticSearchPack packEsSysLogOperate(SysLogOperate bean) {
        ElasticSearchPack result = packElasticSearchPack(bean);

        result.andKeywordEquals("id",bean.getId());
        result.andKeywordEquals("operateType",bean.getOperateType());
        result.andKeywordEquals("operateModule",bean.getOperateModule());
        result.andStringEquals("remoteIp",bean.getRemoteIp());
        result.andStringEquals("createUser",bean.getCreateUser());
        result.andStringLike("operateMessage",bean.getOperateMessage());
        result.andStringDateTimeBetween("createDatetime",bean.getCreateDateTimeStart(),bean.getCreateDateTimeEnd());

        return result;
    }

    /**
     * 日志复杂查询
     *
     * @param logSystem
     * @return
     */
    public static Bson packMongoByLogSystem(SysLogSystem logSystem) {
        Bson bson = new BasicDBObject();

        bson = BsonPackTool.getNumEqualPack(logSystem.getId(), "id", bson);
        bson = BsonPackTool.getNumEqualPack(logSystem.getLogLevel(), "logLevel", bson);
        bson = BsonPackTool.getNumEqualPack(logSystem.getLogModuleId(), "logModuleId", bson);
        bson = BsonPackTool.timeBuilder("createDatetime", bson, logSystem.getCreateDateTimeStart(),logSystem.getCreateDateTimeEnd());
        bson = BsonPackTool.getStringLikerPack(logSystem.getRemoteIp(), "remoteIp", bson);
        bson = BsonPackTool.getStringLikerPack(logSystem.getRequestUrl(), "requestUrl", bson);
        bson = BsonPackTool.getStringLikerPack(logSystem.getLogMethod(), "logMethod", bson);

        return bson;
    }

    public static ElasticSearchPack packEsSysLogSystem(SysLogSystem bean) {
        ElasticSearchPack result = packElasticSearchPack(bean);

        result.andTextEquals("id",bean.getId());
        result.andTextEquals("logLevel",bean.getLogLevel());
        result.andTextEquals("logModuleId",bean.getLogModuleId());
        result.andStringEquals("remoteIp",bean.getRemoteIp());
        result.andTextLike("requestUrl",bean.getRequestUrl());
        result.andKeywordDateTimeBetween("createDatetime",bean.getCreateDateTimeStart(),bean.getCreateDateTimeEnd());

        return result;
    }

    /**
     * 定时任务日志复杂查询
     *
     * @param sysLogTaskTime
     * @return
     */
    public static Bson packMongoByLogTaskTime(SysLogTaskTime sysLogTaskTime) {
        Bson bson = new BasicDBObject();

        bson = BsonPackTool.getNumEqualPack(sysLogTaskTime.getId(), "id", bson);
        bson = BsonPackTool.getStringLikerPack(sysLogTaskTime.getName(), "name", bson);
        bson = BsonPackTool.getStringLikerPack(sysLogTaskTime.getGroupName(), "groupName", bson);
        bson = BsonPackTool.timeBuilder("createDatetime", bson, sysLogTaskTime.getCreateDateTimeStart(),sysLogTaskTime.getCreateDateTimeEnd());

        return bson;
    }

    public static ElasticSearchPack packEsSysLogTaskTime(SysLogTaskTime bean) {
        ElasticSearchPack result = packElasticSearchPack(bean);

        result.andKeywordEquals("id",bean.getId());
        result.andTextLike("name",bean.getName());
        result.andStringEquals("groupName",bean.getGroupName());
        result.andStringEquals("schedulerServerIp",bean.getSchedulerServerIp());
        result.andKeywordDateTimeBetween("createDatetime",bean.getCreateDateTimeStart(),bean.getCreateDateTimeEnd());

        return result;
    }

    public static ElasticSearchPack packEsSysLogConsole(SysLogConsole bean) {
        ElasticSearchPack result = packElasticSearchPack(bean);

        result.andStringEquals("softType",bean.getSoftType());
        result.andStringLeftLike("logHost",bean.getLogHost());
        result.andStringLike("userLoginName",bean.getUserLoginName());
        result.andStringEquals("logLevel",bean.getLogLevel());
        result.andStringLeftLike("executeClassName",bean.getExecuteClassName());
        result.andStringLike("executeMethod",bean.getExecuteMethod());
        result.andStringLike("executeArgs",bean.getExecuteArgs());
        result.andStringLike("executeTitle",bean.getExecuteTitle());
        result.andStringLike("executeMessage",bean.getExecuteMessage());
        result.andStringLike("errorStackTrace",bean.getErrorStackTrace());
//        result.andNumberBetween("executeTime",bean.getErrorStackTrace());
        result.andKeywordDateTimeBetween("createDatetime",bean.getCreateDateTimeStart(),bean.getCreateDateTimeEnd());

        return result;
    }

}
